@@ -5,17 +5,14 @@ use warnings;
 
 use base 'Devel::hdb::App::Base';
 
-our $VERSION = '0.25';
-
-__PACKAGE__->add_route('get', qr(^/db/(.*)), \&assets);
-__PACKAGE__->add_route('get', qr(^/img/(.*)), \&assets);
-__PACKAGE__->add_route('get', '/debugger-gui', sub { assets(@_, 'debugger.html') });
+__PACKAGE__->add_route('get', qr(/db/(.*)), \&assets);
+__PACKAGE__->add_route('get', qr(/img/(.*)), \&assets);
+__PACKAGE__->add_route('get', '/', sub { assets(@_, 'debugger.html') });
 
 sub assets {
     my($class, $app, $env, $file) = @_;
 
     $file =~ s/\.\.//g;  # Remove ..  They're unnecessary and a security risk
-    $file =~ s/^\/debugger-gui//;
     my $file_path = $INC{'Devel/hdb.pm'};
     $file_path =~ s/\.pm$//;
     $file_path .= '/html/'.$file;
@@ -31,12 +28,6 @@ sub assets {
         $type = 'text/html';
     } elsif ($file =~ m/\.css$/) {
         $type = 'text/css';
-    } elsif ( $file =~ m/\.png$/) {
-        $type = 'image/png';
-        $fh->binmode();
-    } elsif ( $file =~ m/\.ico$/) {
-        $type = 'image/x-icon';
-        $fh->binmode();
     } else {
         $type = 'text/plain';
     }
@@ -61,12 +52,12 @@ Devel::hdb::App::Assets - Handler for file assets
 =head1 DESCRIPTION
 
 Registers routes for GET request for /db/.* and /img/.* that serve up files
-located un the html subdirectory of Devel::hdb.  The GET /debugger-gui route returns the
+located un the html subdirectory of Devel::hdb.  The GET / route returns the
 file debugger.html.
 
 =head1 SEE ALSO
 
-L<Devel::hdb>
+Devel::hdb
 
 =head1 AUTHOR
 
@@ -74,5 +65,5 @@ Anthony Brummett <brummett@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2018, Anthony Brummett.  This module is free software. It may
+Copyright 2013, Anthony Brummett.  This module is free software. It may
 be used, redistributed and/or modified under the same terms as Perl itself.
