@@ -139,14 +139,17 @@ function Debugger(sel) {
         // handler to this.elt :(
         var lastControlKeyElement = undefined;
         $(document).keypress(function(e) {
-            //if (e.currentTarget !== document) {
             if (! $(e.target).is('body')) {
                 // Don't handle events for elements like text inputs
                 return;
             }
-            switch (e.keyCode) {
+            if (e.ctrlKey || e.altKey || e.metaKey) {
+                // Don't process when these modifier keys are used
+                // Shift as a modifier is accounted for in e.which
+                return;
+            }
+            switch (e.which) {
                 case 115: // s
-                    //lastControlKeyElement = $('[data-action="stepin"]');
                     lastControlKeyElement = dbg.controlButtons.filter('[data-action="stepin"]')
                             .click();
                     e.stopPropagation();
